@@ -1,7 +1,7 @@
 from PIL import Image, ImageColor, ImageDraw
 
 from . import get_gene_color
-from .logger import MyLogger
+from simple_loggers import SimpleLogger
 
 
 class PNG(object):
@@ -10,7 +10,7 @@ class PNG(object):
         self.image_filename = image_filename
         self.conf_data = conf_data
         self.genedict = genedict
-        self.logger = logger or MyLogger(name='PNG')
+        self.logger = logger or SimpleLogger(name='PNG')
 
     def build_png(self, outfile):
 
